# Prevent accidental changes by using resource locks

> https://docs.microsoft.com/en-us/learn/modules/build-cloud-governance-strategy-azure/3-prevent-changes-resource-locks

A [resource lock](https://docs.microsoft.com/en-us/azure/azure-resource-manager/management/lock-resources?tabs=json) prevents resources from being accidentally deleted or changed.

Even with Azure role-based access control (Azure RBAC) policies in place, there's still a risk that people with the right level of access could delete critical cloud resources. Think of a resource lock as a warning system that reminds you that a resource should not be deleted or changed.

For example, at Tailwind Traders, an IT administrator was performing routine cleanup of unused resources in Azure. The admin accidentally deleted resources that appeared to be unused. But these resources were critical to an application that's used for seasonal promotions. How can resource locks help prevent this kind of incident from happening in the future?

## How do I manage resource locks?

You can manage resource locks from the Azure portal, PowerShell, the Azure CLI, or from an Azure Resource Manager template.

To view, add, or delete locks in the Azure portal, go to the Settings section of any resource's Settings pane in the Azure portal.

Here's an example that shows how to add a resource lock from the Azure portal. You'll apply a similar resource lock in the next part.

![](https://docs.microsoft.com/en-us/learn/azure-fundamentals/build-cloud-governance-strategy-azure/media/7-portal-add-lock-ebc3d24c.png)

## What levels of locking are available?

You can apply locks to a subscription, a resource group, or an individual resource.
You can set the lock level to **CanNotDelete** or **ReadOnly**.

- CanNotDelete means authorized people can still read and modify a resource, but they can't delete the resource without first removing the lock.
- ReadOnly means authorized people can read a resource, but they can't delete or change the resource.
Applying this lock is like restricting all authorized users to the permissions granted by the Reader role in Azure RBAC.

## How do I delete or change a locked resource?

Although locking helps prevent accidental changes, you can still make changes by following a two-step process.

To modify a locked resource, you must first remove the lock.
After you remove the lock, you can apply any action you have permissions to perform.
This additional step allows the action to be taken, but it helps protect your administrators from doing something they might not have intended to do.

Resource locks apply regardless of RBAC permissions.
Even if you're an owner of the resource, you must still remove the lock before you can perform the blocked activity.

## Combine resource locks with Azure Blueprints

What if a cloud administrator accidentally deletes a resource lock?
If the resource lock is removed, its associated resources can be changed or deleted.

To make the protection process more robust, you can combine resource locks with Azure Blueprints.
Azure Blueprints enables you to define the set of standard Azure resources that your organization requires.
For example, you can define a blueprint that specifies that a certain resource lock must exist.
Azure Blueprints can automatically replace the resource lock if that lock is removed.

[< 5: Describe identity, governance, privacy, and compliance features](./5-lp-az-900.md)